@@ -16,7 +16,7 @@ from .redis_util import RedisUtil
 
 
 class CadUtil(object):
-    def __init__(self, redis_url_str: str = None, key: str = None, cache_key: str = None):
+    def __init__(self, redis_url_str: str = None, key: str = None, cache_key: str = None, is_log: bool = True):
         """
 
         :param redis_url_str:
@@ -33,6 +33,7 @@ class CadUtil(object):
             self._cache_key = cache_key
         self._redis_client = RedisUtil(url_str=redis_url_str).redis
         self._aes_client = AESUtil(encrypt_key=key)
+        self._is_log = is_log
 
     @LogUtil()
     def get(self, ak: str) -> dict:
