@@ -4,13 +4,13 @@
 # @Author : Bruce Liu /Lin Luo
 # @Mail   : 15869300264@163.com
 import socket
-from cad import __version__ as version
 from datetime import datetime
 from functools import wraps
 from json import dumps
 
 from dynaconf import settings as dynasettings
 
+from cad import __version__ as version
 from .exceptions import CadException
 from .redis_util import RedisUtil
 
@@ -36,7 +36,7 @@ def basic_info() -> dict:
     :return:
     """
     hostname = socket.gethostname()
-    return {'hostname': hostname, 'ip': ip, 'time': str(datetime.now()),'version': version}
+    return {'hostname': hostname, 'ip': ip, 'time': str(datetime.now()), 'version': version}
 
 
 class LogUtil(object):
@@ -61,6 +61,8 @@ class LogUtil(object):
         def inner(func_self, *args, **kwargs):
             try:
                 res = func(func_self, *args, **kwargs)
+                if not getattr(func_self, '_is_log', True):
+                    return res
                 # 根据不同的函数，执行不同的处理方法
                 if func.__name__ == 'check':
                     items = self._app_config_util_check(func_self, *args, **kwargs)
